==> application-ui-container-v2.2.0-49.tar.gz: package/docs/components/JumpLinks/examples/JumpLinks.md <==
---
id: Jump links
section: components
cssPrefix: pf-c-jump-links
beta: true
---## Examples

### Horizontal default

```html
<nav class="pf-c-jump-links" aria-label="Local">
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>
```

### Horizontal with centered list

```html
<nav class="pf-c-jump-links pf-m-center" aria-label="Local">
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>
```

### Horizontal with label

```html
<nav class="pf-c-jump-links" aria-label="Local">
  <div class="pf-c-jump-links__main">
    <div class="pf-c-jump-links__label">Jump to section</div>
    <ul class="pf-c-jump-links__list">
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item pf-m-current">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Active section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
    </ul>
  </div>
</nav>
<br/>
<nav class="pf-c-jump-links pf-m-center" aria-label="Local">
  <div class="pf-c-jump-links__main">
    <div class="pf-c-jump-links__label">Jump to section</div>
    <ul class="pf-c-jump-links__list">
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item pf-m-current">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Active section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
    </ul>
  </div>
</nav>
```

### Vertical default

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>
```

### Vertical with label

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <div class="pf-c-jump-links__label">Jump to section</div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>
```

### Vertical with inactive subsections

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <div class="pf-c-jump-links__label">Jump to section</div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
      <ul class="pf-c-jump-links__list">
        <li class="pf-c-jump-links__item">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Inactive subsection</span>
          </a>
        </li>
        <li class="pf-c-jump-links__item">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Inactive subsection</span>
          </a>
        </li>
      </ul>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>
```

### Vertical with active subsections

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <div class="pf-c-jump-links__label">Jump to section</div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
      <ul class="pf-c-jump-links__list">
        <li class="pf-c-jump-links__item pf-m-current">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Active subsection</span>
          </a>
        </li>
        <li class="pf-c-jump-links__item">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Inactive subsection</span>
          </a>
        </li>
      </ul>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>
```

## Documentation

### Overview

### Accessibility

| Attribute | Applied to | Outcome |
| --------- | ---------- | ------- |
|           |            |         |

### Usage

| Class                         | Applied to               | Outcome                                                                                                |
| ----------------------------- | ------------------------ | ------------------------------------------------------------------------------------------------------ |
| `.pf-c-jump-links`            | `<div>`                  | Initiates the jump links container.                                                                    |
| `.pf-c-jump-links__main`      | `<div>`                  | Initiates the jump links main container for when a label and list is used in the horizontal variation. |
| `.pf-c-jump-links__list`      | `<ul>`                   | Initiates the jump links list.                                                                         |
| `.pf-c-jump-links__item`      | `<li>`                   | Initiates the jump links list item.                                                                    |
| `.pf-c-jump-links__link`      | `<button>`               | Initiates the jump links link.                                                                         |
| `.pf-c-jump-links__label`     | `<div>`                  | Initiates the jump links label.                                                                        |
| `.pf-c-jump-links__link-text` | `<div>`                  | Initiates the jump links link text.                                                                    |
| `.pf-m-vertical`              | `.pf-c-jump-links`       | Modifies the jump links component to be vertical.                                                      |
| `.pf-m-current`               | `.pf-c-jump-links__item` | Modifies the jump links item to be current.                                                            |
| `.pf-m-center`                | `.pf-c-jump-links`       | Modifies the jump links component to center its list and label.                                        |

==> application-ui-container-v2.3.10-6.tar.gz: package/docs/components/JumpLinks/examples/JumpLinks.md <==
---
id: Jump links
section: components
cssPrefix: pf-c-jump-links
beta: true
---## Examples

### Horizontal default

```html
<nav class="pf-c-jump-links" aria-label="Local">
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Horizontal with centered list

```html
<nav class="pf-c-jump-links pf-m-center" aria-label="Local">
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Horizontal with label

```html
<nav class="pf-c-jump-links" aria-label="Local">
  <div class="pf-c-jump-links__main">
    <div class="pf-c-jump-links__header">
      <div class="pf-c-jump-links__label">Jump to section</div>
    </div>
    <ul class="pf-c-jump-links__list">
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item pf-m-current">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Active section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
    </ul>
  </div>
</nav>
<br />
<nav class="pf-c-jump-links pf-m-center" aria-label="Local">
  <div class="pf-c-jump-links__main">
    <div class="pf-c-jump-links__header">
      <div class="pf-c-jump-links__label">Jump to section</div>
    </div>
    <ul class="pf-c-jump-links__list">
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item pf-m-current">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Active section</span>
        </a>
      </li>
      <li class="pf-c-jump-links__item">
        <a class="pf-c-jump-links__link" href="#">
          <span class="pf-c-jump-links__link-text">Inactive section</span>
        </a>
      </li>
    </ul>
  </div>
</nav>

```

### Vertical default

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Vertical with label

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <div class="pf-c-jump-links__header">
    <div class="pf-c-jump-links__label">Jump to section</div>
  </div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Vertical with inactive subsections

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <div class="pf-c-jump-links__header">
    <div class="pf-c-jump-links__label">Jump to section</div>
  </div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
      <ul class="pf-c-jump-links__list">
        <li class="pf-c-jump-links__item">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Inactive subsection</span>
          </a>
        </li>
        <li class="pf-c-jump-links__item">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Inactive subsection</span>
          </a>
        </li>
      </ul>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Vertical with active subsections

```html
<nav class="pf-c-jump-links pf-m-vertical" aria-label="Local">
  <div class="pf-c-jump-links__header">
    <div class="pf-c-jump-links__label">Jump to section</div>
  </div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
      <ul class="pf-c-jump-links__list">
        <li class="pf-c-jump-links__item pf-m-current">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Active subsection</span>
          </a>
        </li>
        <li class="pf-c-jump-links__item">
          <a class="pf-c-jump-links__link" href="#">
            <span class="pf-c-jump-links__link-text">Inactive subsection</span>
          </a>
        </li>
      </ul>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Expandable

```html
<nav class="pf-c-jump-links pf-m-vertical pf-m-expandable" aria-label="Local">
  <div class="pf-c-jump-links__header">
    <div class="pf-c-jump-links__toggle">
      <button
        class="pf-c-button pf-m-plain"
        type="button"
        aria-label="Details"
        aria-expanded="false"
        id="jump-links-expandable-toggle"
        aria-labelledby="jump-links-expandable-label jump-links-expandable-toggle"
      >
        <span class="pf-c-jump-links__toggle-icon">
          <i class="fas fa-angle-right" aria-hidden="true"></i>
        </span>
      </button>
    </div>
    <div
      class="pf-c-jump-links__label"
      id="jump-links-expandable-label"
    >Jump to section</div>
  </div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Expanded

```html
<nav
  class="pf-c-jump-links pf-m-vertical pf-m-expandable pf-m-expanded"
  aria-label="Local"
>
  <div class="pf-c-jump-links__header">
    <div class="pf-c-jump-links__toggle">
      <button
        class="pf-c-button pf-m-plain"
        type="button"
        aria-label="Details"
        aria-expanded="true"
        id="jump-links-expanded-toggle"
        aria-labelledby="jump-links-expanded-label jump-links-expanded-toggle"
      >
        <span class="pf-c-jump-links__toggle-icon">
          <i class="fas fa-angle-right" aria-hidden="true"></i>
        </span>
      </button>
    </div>
    <div
      class="pf-c-jump-links__label"
      id="jump-links-expanded-label"
    >Jump to section</div>
  </div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Expandable (responsive)

```html
<nav
  class="pf-c-jump-links pf-m-vertical pf-m-non-expandable-on-md pf-m-expandable-on-lg pf-m-non-expandable-on-xl pf-m-expandable"
  aria-label="Local"
>
  <div class="pf-c-jump-links__header">
    <div class="pf-c-jump-links__toggle">
      <button
        class="pf-c-button pf-m-plain"
        type="button"
        aria-label="Details"
        aria-expanded="false"
        id="jump-links-expandable-responsive-toggle"
        aria-labelledby="jump-links-expandable-responsive-label jump-links-expandable-responsive-toggle"
      >
        <span class="pf-c-jump-links__toggle-icon">
          <i class="fas fa-angle-right" aria-hidden="true"></i>
        </span>
      </button>
    </div>
    <div
      class="pf-c-jump-links__label"
      id="jump-links-expandable-responsive-label"
    >Jump to section</div>
  </div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

### Expandable (responsive) with toggle label

```html
<nav
  class="pf-c-jump-links pf-m-vertical pf-m-non-expandable-on-md pf-m-expandable-on-lg pf-m-non-expandable-on-xl pf-m-expandable"
  aria-label="Local"
>
  <div class="pf-c-jump-links__header">
    <div class="pf-c-jump-links__toggle">
      <button
        class="pf-c-button pf-m-plain"
        type="button"
        aria-label="Details"
        aria-expanded="false"
        id="jump-links-expandable-responsive-with-toggle-label-toggle"
        aria-labelledby="jump-links-expandable-responsive-with-toggle-label-label jump-links-expandable-responsive-with-toggle-label-toggle"
      >
        <span class="pf-c-jump-links__toggle-icon">
          <i class="fas fa-angle-right" aria-hidden="true"></i>
        </span>
      </button>
    </div>
    <div
      class="pf-c-jump-links__label pf-m-toggle"
      id="jump-links-expandable-responsive-with-toggle-label-label"
    >Jump to section</div>
  </div>
  <ul class="pf-c-jump-links__list">
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item pf-m-current">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Active section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
    <li class="pf-c-jump-links__item">
      <a class="pf-c-jump-links__link" href="#">
        <span class="pf-c-jump-links__link-text">Inactive section</span>
      </a>
    </li>
  </ul>
</nav>

```

## Documentation

### Overview

### Accessibility

| Attribute | Applied to | Outcome |
| --------- | ---------- | ------- |
|           |            |         |

### Usage

| Class                                    | Applied to                | Outcome                                                                                                         |
| ---------------------------------------- | ------------------------- | --------------------------------------------------------------------------------------------------------------- |
| `.pf-c-jump-links`                       | `<div>`                   | Initiates the jump links container.                                                                             |
| `.pf-c-jump-links__main`                 | `<div>`                   | Initiates the jump links main container for when a label and list is used in the horizontal variation.          |
| `.pf-c-jump-links__list`                 | `<ul>`                    | Initiates the jump links list.                                                                                  |
| `.pf-c-jump-links__item`                 | `<li>`                    | Initiates the jump links list item.                                                                             |
| `.pf-c-jump-links__link`                 | `<button>`                | Initiates the jump links link.                                                                                  |
| `.pf-c-jump-links__header`               | `<div>`                   | Initiates the jump links header.                                                                                |
| `.pf-c-jump-links__toggle`               | `<div>`                   | Initiates the jump links expandable toggle.                                                                     |
| `.pf-c-jump-links__toggle-icon`          | `<div>`                   | Initiates the jump links expandable toggle icon.                                                                |
| `.pf-c-jump-links__label`                | `<div>`                   | Initiates the jump links label.                                                                                 |
| `.pf-c-jump-links__link-text`            | `<div>`                   | Initiates the jump links link text.                                                                             |
| `.pf-m-vertical`                         | `.pf-c-jump-links`        | Modifies the jump links component to be vertical.                                                               |
| `.pf-m-center`                           | `.pf-c-jump-links`        | Modifies the jump links component to center its list and label.                                                 |
| `.pf-m-expandable{-on-[breakpoint]}`     | `.pf-c-jump-links`        | Modifies the jump links component to be expandable via a toggle. **Note:** works with vertical jump links only. |
| `.pf-m-non-expandable{-on-[breakpoint]}` | `.pf-c-jump-links`        | Modifies the jump links component to be non-expandable.                                                         |
| `.pf-m-expanded`                         | `.pf-c-jump-links`        | Modifies the expandable jump links component for the expanded state.                                            |
| `.pf-m-current`                          | `.pf-c-jump-links__item`  | Modifies the jump links item to be current.                                                                     |
| `.pf-m-toggle`                           | `.pf-c-jump-links__label` | Modifies the jump links label to serve as toggle text for when the jump links are expandable.                   |
